api

package
v0.0.0-...-8576238 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 25, 2019 License: GPL-3.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Blocks []coind.Block
var ConfigFile = coind.LoadConfig("./config/config.json")

Functions

func GetBlock

func GetBlock(w http.ResponseWriter, r *http.Request)

GetBlockObject

func GetBlockFromDBHeight

func GetBlockFromDBHeight(w http.ResponseWriter, r *http.Request)

/ GetBlock from DB using Height. Couldn't use height has Primary index as bolt doesn't like '0' or block 0 / Made my own dbBlock type with it's own "ID"

func GetBlockchainInfo

func GetBlockchainInfo(w http.ResponseWriter, r *http.Request)

GetBlockchainInfo

func GetCoinCodexData

func GetCoinCodexData(w http.ResponseWriter, r *http.Request)

func GetTX

func GetTX(w http.ResponseWriter, r *http.Request)

GetTX

func GetTXFromDB

func GetTXFromDB(w http.ResponseWriter, r *http.Request)

Get TX from TXID

func GetWalletTransactions

func GetWalletTransactions(w http.ResponseWriter, r *http.Request)

func IndexRoute

func IndexRoute(w http.ResponseWriter, r *http.Request)

/ To show a simple index page with the coin price info

Types

This section is empty.

Jump to