Documentation
¶
Index ¶
- Variables
- func GetBlock(w http.ResponseWriter, r *http.Request)
- func GetBlockFromDBHeight(w http.ResponseWriter, r *http.Request)
- func GetBlockchainInfo(w http.ResponseWriter, r *http.Request)
- func GetCoinCodexData(w http.ResponseWriter, r *http.Request)
- func GetTX(w http.ResponseWriter, r *http.Request)
- func GetTXFromDB(w http.ResponseWriter, r *http.Request)
- func GetWalletTransactions(w http.ResponseWriter, r *http.Request)
- func IndexRoute(w http.ResponseWriter, r *http.Request)
Constants ¶
This section is empty.
Variables ¶
var Blocks []coind.Block
var ConfigFile = coind.LoadConfig("./config/config.json")
Functions ¶
func GetBlockFromDBHeight ¶
func GetBlockFromDBHeight(w http.ResponseWriter, r *http.Request)
/ GetBlock from DB using Height. Couldn't use height has Primary index as bolt doesn't like '0' or block 0 / Made my own dbBlock type with it's own "ID"
func GetBlockchainInfo ¶
func GetBlockchainInfo(w http.ResponseWriter, r *http.Request)
GetBlockchainInfo
func GetCoinCodexData ¶
func GetCoinCodexData(w http.ResponseWriter, r *http.Request)
func GetWalletTransactions ¶
func GetWalletTransactions(w http.ResponseWriter, r *http.Request)
func IndexRoute ¶
func IndexRoute(w http.ResponseWriter, r *http.Request)
/ To show a simple index page with the coin price info
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.